-- This program is free software: you can redistribute it and/or modify
-- it under the terms of the GNU General Public License as published by
-- the Free Software Foundation, either version 3 of the License, or
-- any later version.
   
-- This program is distributed in the hope that it will be useful,
-- but WITHOUT ANY WARRANTY; without even the implied warranty of
-- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-- GNU General Public License for more details.
   
-- You should have received a copy of the GNU General Public License
-- along with this program. If not, see http://www.gnu.org/licenses/.

-----------------------------------------------------------------------

-- Written by Wesley "keyboard monkey" Werner 2015
-- https://github.com/wesleywerner/

alignments = {
    "center", 
    "right", 
    "bottom left", 
    "bottom", 
    "bottom right",
    "top left", 
    "top", 
    "top right", 
    "left", 
    }

inception = {}

display = 1

screen = {x=0, y=0}

box = cutter.cut(0.5, 0.5, alignments[display])

function love.draw()
    
    love.graphics.setColor(255, 255, 255)
    love.graphics.print("Hit <space> to change alignment, hit <enter> to subdivide.")
    
    -- Previous boxes
    for _, box in pairs(inception) do
        love.graphics.setColor(200, 200, 255)
        love.graphics.rectangle("line", 
            box.x, 
            box.y, 
            box.width, 
            box.height)
    end
    
    -- Current box
    love.graphics.setColor(200, 200, 255)
    love.graphics.rectangle("fill", 
        box.x, 
        box.y, 
        box.width, 
        box.height)
    
    -- Title
    love.graphics.setColor(255, 0, 0)
    local title = alignments[display] .. " aligned"
    local titleSize = love.graphics.getFont():getWidth(title)
    love.graphics.print(title, 
            box.center.x - (titleSize/2), 
            box.center.y)
end

function love.keypressed(key)
    if key == " " then
        display = display + 1
        if (display > #alignments) then display = 1 end
        box = cutter.cut(0.5, 0.5, alignments[display], screen)
    elseif key == "return" then
        table.insert(inception, box)
        -- current box becomes the new screen
        screen = box
        box = cutter.cut(0.5, 0.5, alignments[display], screen)
    elseif key == "escape" then
        love.event.quit()
    end
end
